@@ -21,11 +21,12 @@
 import os
 import re
 import shutil
+import unidecode
 import xdg.DesktopEntry
 import xdg.Menu
 
-from execute import *
-from filemonitor import monitor as filemonitor
+from .execute import *
+from .filemonitor import monitor as filemonitor
 from gi.repository import Gtk, Gdk, GLib
 from gi.repository import Pango
 from gi.repository import GObject
@@ -61,10 +62,10 @@ class IconManager(GObject.GObject):
         contents = frozenset(os.listdir(self.iconDir)) - frozenset(('applications', 'applications.list'))
         for fn in contents:
             if os.path.isfile(os.path.join(self.iconDir, fn)):
-                print "Removing file : " + os.path.join(self.iconDir, fn)
+                print("Removing file : " + os.path.join(self.iconDir, fn))
                 os.remove(os.path.join(self.iconDir, fn))
             else:
-                print os.path.join(self.iconDir, fn) + " is not a file, skipping delete."
+                print(os.path.join(self.iconDir, fn) + " is not a file, skipping delete.")
 
         self.defaultTheme.append_search_path(self.iconDir)
 
@@ -121,8 +122,8 @@ class IconManager(GObject.GObject):
                 image = None
 
             return image
-        except Exception, e:
-            print "Exception " + e.__class__.__name__ + ": " + e.message
+        except Exception as e:
+            print("Exception " + e.__class__.__name__ + ": " + e.message)
             return None
 
     def themeChanged( self, theme ):
@@ -162,7 +163,7 @@ class easyButton( Gtk.Button ):
 
         if labels:
             for label in labels:
-                if isinstance( label, basestring ):
+                if isinstance( label, str ):
                     self.addLabel( label )
                 elif isinstance( label, list ):
                     self.addLabel( label[0], label[1] )
@@ -172,6 +173,8 @@ class easyButton( Gtk.Button ):
         HBox1.show()
         self.add( HBox1 )
 
+        self.set_events(Gdk.EventMask.POINTER_MOTION_MASK)
+        self.connectSelf( "motion-notify-event", self.onMotion )
         self.connectSelf( "enter-notify-event", self.onEnter )
         self.connectSelf( "focus-in-event", self.onFocusIn )
         self.connectSelf( "focus-out-event", self.onFocusOut )
@@ -183,8 +186,16 @@ class easyButton( Gtk.Button ):
     def connectSelf( self, event, callback ):
         self.connections.append( self.connect( event, callback ) )
 
+    def onMotion( self, widget, event ):
+        # Only grab if mouse is actually hovering
+        if self.mouse_entered:
+            self.grab_focus()
+            self.mouse_entered = False
+
     def onEnter( self, widget, event ):
-        self.grab_focus()
+        # Prevent false "enter" notifications by determining
+        # whether the mouse is actually hovering on the button.
+        self.mouse_entered = True
 
     def onFocusIn( self, widget, event ):
         self.set_state_flags( Gtk.StateFlags.PRELIGHT, False )
@@ -233,7 +244,7 @@ class easyButton( Gtk.Button ):
 
         icon = iconManager.getIcon( self.iconName, iconSize )
         if icon is None:
-            icon = iconManager.getIcon( "application-default-icon", iconSize )
+            icon = iconManager.getIcon( "gtk-missing-image", iconSize )
 
         return icon
 
@@ -340,8 +351,8 @@ class ApplicationLauncher( easyButton ):
             if os.path.exists (self.startupFilePath):
                 self.startupMonitorId = filemonitor.addMonitor( self.startupFilePath, self.startupFileChanged )
 
-        except Exception, e:
-            print e
+        except Exception as e:
+            print(e)
             self.appName            = ""
             self.appGenericName     = ""
             self.appComment         = ""
@@ -396,14 +407,8 @@ class ApplicationLauncher( easyButton ):
         self.show()
         return True
 
-    def strip_accents(self, string):
-        value = string
-        if isinstance(string, unicode):
-            try:
-                value = string.encode('UTF8', 'ignore')
-            except:
-                pass
-        return value
+    def strip_accents(self, value):
+        return unidecode.unidecode(value)
 
     def getTooltip( self ):
         tooltip = self.appName
@@ -490,7 +495,7 @@ class ApplicationLauncher( easyButton ):
         base = os.path.basename( self.desktopFile )
         for dir in self.appDirs:
             if os.path.exists( os.path.join( dir, base ) ):
-                # print os.path.join( dir, base ), self.desktopFile
+                # print(os.path.join( dir, base ), self.desktopFile)
                 self.loadDesktopEntry( xdg.DesktopEntry.DesktopEntry( os.path.join( dir, base ) ) )
                 for child in self.labelBox:
                     child.destroy()
@@ -540,8 +545,8 @@ class MenuApplicationLauncher( ApplicationLauncher ):
                     #appComment = "<b>%s</b>" % (appComment);
                 appName = "<b>%s</b>" % (appName);
                 appComment = "<b>%s</b>" % (appComment);
-            except Exception, detail:
-                print detail
+            except Exception as detail:
+                print(detail)
                 pass
 
         if self.showComment and self.appComment != "":
